#!/usr/bin/env python3

import sys
import math
from astropy.time import Time

DEG = math.pi/180.

def main():

    f = open("Sky.lite", "a")

    print("# JD (TDB; i.e. uncorrected for LITE) & separation rho [arcsec] & position angle theta [deg] & major [arcsec] & minor [arcsec] & PA [deg] of uncertainty ellipse & d [au] & l [deg] & b [deg] (all from Horizons; i.e. corrected for LITE) & Besselian year & dataset");

    for line in sys.stdin:
        if line[0:1] == "#" or len(line) < 2:
            continue
        l = line.split()

        t1 = Time(l[1], format="isot", scale="utc")
        t2 = t1.tdb
        jd = t2.jd
        x = float(l[2])
        y = float(l[3])
        major = float(l[4])
        minor = float(l[5])
        d = l[6]
        l_ = l[7]
        b = l[8]
        dataset = l[9]

        sep = math.sqrt(x**2+y**2)
        ang = math.atan2(x,y)
        if ang < 0.0:
            ang += 2.*math.pi
        PA_ellipse = 0.0
#        sigma = 0.01
#        major = sigma
#        minor = sigma

        # lite = d/c * au/day
        lite = 0.0  # it's implemented in the code!
        jd = jd - lite

        bessel = 1900.0 + (jd - 2415020.31352) / 365.242198781
#        if bessel < 1981.0:
#            dataset = "SKYTEL"
#        elif bessel < 2009.0:
#            dataset = "DESCAMPS"
#        elif bessel < 2018.0:
#            dataset = "SPHERE2017"
#        else:
#            dataset = "SPHERE2018"

        print("%.6f	%.6f	%.6f	%.6f	%.6f	%.6f	%s	%s	%s	%.6f	%s	# %s %s" % (jd, sep, ang/DEG, major, minor, PA_ellipse, d, l_, b, bessel, dataset, l[0], l[1]))

        f.write("lite = %f d = %f min\n" % (lite, lite*1440.))

    f.close()

if __name__ == "__main__":
    main()


